![](https://github.com/flikka/flass/workflows/Flass%20CI/badge.svg)
![](https://github.com/flikka/flass/workflows/Flass%20PyPI/badge.svg)
![](https://github.com/flikka/flass/workflows/Dockerhub/badge.svg)

# So, you want flass?

Flass is great.

## Getting started

`pip install --upgrade flass` for the latest release.

`pip install git+https://github.com/flikka/flass` for bleeding edge Flass.

## Run flass after installing

`flass` supports some command line arguments, see help by running `flass --help``

There are a couple of datasets supported out of the box. Try `flass --dataset mnist`
